Index: doc/options.txt
===================================================================
--- doc/options.txt	(revision 4477)
+++ doc/options.txt	(working copy)
@@ -61,7 +61,7 @@
 
 ;--gmapsupp
 : 	Create a gmapsupp.img file that can be uploaded to a Garmin or
-placed in "/Garmin" in a microSD card (such as by mounting the
+placed in the /Garmin folder of a microSD card (such as by mounting the
 device in USB mass storage mode). It can be used on already
 compiled img files, or if the input files are not already compiled
 then they are compiled first and then the gmapsupp is created.
@@ -96,13 +96,23 @@
 that it is unique and does not clash with others.
 
 ;--description=text
-: 	Set the descriptive text for the map. This may be displayed in
-QLandkarte, MapSource or on a GPS, where it is normally shown
-below the family name. Example: --description="Germany, Denmark"
-Please note: if you use splitter to build a template.args file
-and pass it to mkgmap, then that file may contain a "description"
-that will override this option. To prevent splitter from overriding
-your description, place the --description option after "-c template.args".
+: 	Set the descriptive text for individual tiles and gmapsupp.img.
+Map tiles take the most recent --description before the --input-file
+option that defines the tile. Because gmapsupp.img is created after all
+the other tiles have been processed, gmapsupp.img takes the last --description
+found in the command line, regardless of where the --gmapsupp option is placed
+in the command line.
+<p>
+Note that if you use splitter with its --geonames-file option or its own --description
+option, the generated template.args file includes --description values that will apply
+to individual tiles. In this case it is not possible to override splitter's
+description for individual tiles from the mkgmap command line.
+Placing the mkgmap --description option after -c template.args ensures that the
+value is applied to gmapsupp.img.
+<p>
+Different GPS devices, MapSource, Basecamp and QLandkarte handle descriptions
+inconsistently. Some display the description when selecting maps or tiles,
+others use the family name.
 
 ;--country-name=name
 : 	Set the map's country name. The default is "COUNTRY".
@@ -338,28 +348,20 @@
 
 === Style options ===
 
-;--style-file=filename
-: 	Specify an external file to obtain the style from.  "file" can
-be a directory containing files such as info, lines, options
-(see resources/styles/default for an example).  The directory
-path must be absolute or relative to the current working
-directory when mkgmap is invoked.
+;--style-file=directory|zip-filename|url
+: 	Specify the path to a directory, zip file or url containing style information.
+A style is composed of a group of files and typically contains the following files:
+version, info, options, points, lines, polygons, relations - see the style manual
+for further details.
 <p>
-The file can be a zip file containing the files instead of a
-directory.
-<p>
-The files can be at the top level or contained in a folder within
-the zip file.  If the zip file contains more than one top level
-folder then each folder is the name of a style that can be selected
+The style files can be in the specified directory or contained in a sub-directory.
+If styles are contained in sub-directories then the required style must be specified
 with the --style option.
-<p>
-The argument can also be a URL that specifies the location of a
-style file.
 
 ;--style=name
 : 	Specify a style name. Must be used if --style-file points to a
-directory or zip file containing multiple styles. If --style-file
-is not used, it selects one of the built-in styles.
+location containing multiple styles. If used without also
+specifying --style-file, it selects one of the built-in styles.
 
 ;--style-option=tag[=value][;tag[=value]...]
 : 	Provide a semicolon separated list of tags which can be used in the style.
@@ -493,16 +495,16 @@
 called hgt files, which typically cover 1 degree latitude * 1 degree longitude
 and are named by the coordinates of their bottom left corner (e.g. N53E009). They
 contain height information in a grid of points. Typical hgt files contain either
-1'' or 3'' data. 3'' files have 1201 * 1201 points, which gives
-2 * 1201 * 1201 = 2.884.802 bytes. 1'' files have 3601 * 3601 points, which gives
-2 * 3601 * 3601 = 25.934.402 bytes. Other files are supported as long as the
-formula sqrt(size/2) gives an integer value.
+1 arc second or 3 arc second data. 3 arc second files have 1201 x 1201 points, which means
+files contain 2 x 1201 x 1201 = 2,884,802 bytes. 1 arc second files have 3601 x 3601 points,
+with a file size of 25,934,402 bytes. Other files are supported as long as the
+formula sqrt(filesize/2) gives an integer value.
 
 ;--dem=path[,path...]
 :   The option expects a comma separated list of paths to directories or zip
 files containing *.hgt files. Directories are searched for *.hgt files
 and also for *.hgt.zip and *.zip files.
-:   The list is searched in the given order, so if you want to use 1'' files
+:   The list is searched in the given order, so if you want to use 1 arc second files
 make sure that they are found first. There are different sources for *.hgt
 files, some have so called voids which are areas without data. Those should be
 avoided.
@@ -514,11 +516,11 @@
 Basecamp you only need one zoom level, for GPS devices you need one for each
 resolution given with the --levels option. The actual values are given as
 distance between two DEM points and should be a multiple or submultiple of the
-distance between two points in the hgt file, that is 3314 for 1'' and 9942 for
-3''. Higher distances mean lower resolution and thus fewer bytes in the map.
+distance between two points in the hgt file, that is 3314 for 1 arc second and 9942 for
+3 arc second. Higher distances mean lower resolution and thus fewer bytes in the map.
 Reasonable values for the highest resolution should not be much smaller than
-50% hgt resolution, that is somewhere between 1648 and 5520 for 1'' hgt input
-files (3312 is often used), and 5520 to 9942 for 3'' hgt input files.
+50% hgt resolution, that is somewhere between 1648 and 5520 for 1 arc second hgt input
+files (3312 is often used), and 5520 to 9942 for 3 arc second hgt input files.
 :	Example which should work with levels="0:24, 1:22, 2:20, 3:18":
 :	--dem-dists=3312,13248,26512,53024
 :	This was found in a Garmin Demo map for transalpin data created 2009.
@@ -899,8 +901,7 @@
 ;--poi-address
 : 	Enable address / phone information to POIs. Address info is
 read according to the "Karlsruhe" tagging schema. Automatic
-filling of missing information could be enabled using the
-"location-autofill" option.
+filling of missing information could be enabled using the --location-autofill option.
 Default is enabled, use --no-poi-address to disable.
 
 ;--verbose
